@@ -65,11 +65,12 @@ class SendSettings:
 class EmailServiceV2Connector:
     @dataclass(kw_only=True)
     class Config(AbmServiceConnector.Config):
-        server_name: str
         sender_name: str
         send_priority: SendPriority = SendPriority.medium
 
-    Context = AbmServiceConnector.Context
+    @dataclass
+    class Context(AbmServiceConnector):
+        project_name: str
 
     def __init__(self, config: Config, context: Context) -> None:
         self._config = config
@@ -134,4 +135,4 @@ class EmailServiceV2Connector:
         return email_id
 
     def _construct_server_name_header(self) -> dict[str, str]:
-        return {"server_name": self._config.server_name}
+        return {"server_name": self._context.project_name}
